==> haskell-equivalence-0.4.1-51-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 equivalence
version:              0.4.1
visibility:           public
id:                   equivalence-0.4.1-KqSlwudRo3WA7JdfM4dXrf
key:                  equivalence-0.4.1-KqSlwudRo3WA7JdfM4dXrf
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  50770e5f2d2ef4d5b8a68a9b67774a37
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-9.2.8/site-local/equivalence-0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/equivalence-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-equivalence
hs-libraries:         HSequivalence-0.4.1-KqSlwudRo3WA7JdfM4dXrf
depends:
    STMonadTrans-0.4.8-4ALWQnVdTSzBbw8PY2nTV7 base-4.16.4.0
    containers-0.6.5.1 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-equivalence-0.4.1-79.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-equivalence.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 equivalence
version:              0.4.1
visibility:           public
id:                   equivalence-0.4.1-7ZjwM8fIRO89VjIei1RA49
key:                  equivalence-0.4.1-7ZjwM8fIRO89VjIei1RA49
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Patrick Bahr
stability:            provisional
homepage:             https://github.com/pa-ba/equivalence
synopsis:
    Maintaining an equivalence relation implemented as union-find using STT.

description:
    This is an implementation of Tarjan'\''s Union-Find algorithm (Robert
    E. Tarjan. "Efficiency of a Good But Not Linear Set Union
    Algorithm", JACM 22(2), 1975) in order to maintain an equivalence
    relation.
    This implementation is a port of the /union-find/ package using the
    ST monad transformer (instead of the IO monad).

category:             Algorithms, Data
abi:                  6791a0601d2cef116b4a89b23c4e1d21
exposed:              True
exposed-modules:      Data.Equivalence.Monad Data.Equivalence.STT
import-dirs:          /usr/lib/ghc-9.4.8/site-local/equivalence-0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/equivalence-0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/equivalence-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-equivalence
hs-libraries:         HSequivalence-0.4.1-7ZjwM8fIRO89VjIei1RA49
depends:
    STMonadTrans-0.4.8-4pvamdshCi4HAppfo23UWI base-4.17.2.1
    containers-0.6.7 mtl-2.2.2 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-equivalence/html/equivalence.haddock
haddock-html:         /usr/share/doc/haskell-equivalence/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
